Breq
====

A simple library to facilitate browsing/paging through Web service requests.

TODOs
-----

* Documentation with examples

Contributing
------------

1. Fork `the repository`_ on GitHub
2. Commit your changes to the **develop** branch
3. Write test(s) for any new feature
4. Push your changes and send a pull request

.. _`the repository`: http://github.com/yaph/breq